@@ -3,8 +3,8 @@ package Lingua::Tokenize;
 use strict;
 use Carp;
 
-# $Header: /var/cvsroot/Lingua-Tokenize/lib/Lingua/Tokenize.pm,v 1.12 2005/06/26 06:33:06 alex Exp $
-our $VERSION='0.4';
+# $Header: /var/cvsroot/Lingua-Tokenize/lib/Lingua/Tokenize.pm,v 1.13 2005/07/06 09:17:40 alex Exp $
+our $VERSION='0.6';
 
 =head1 NAME
 
@@ -174,7 +174,7 @@ sub tokenize {
         elsif( $char =~ /[$cl_finite\.]/ && $slice[0] =~ /[\s$cl_quote]/ ) {
             # end of sentence?
             # --> part a)
-            if ( ($slice[1] =~ /[A-Z$cl_quote\s]/ && 
+            if ( $slice[1] && ( $slice[1] =~ /[A-Z$cl_quote\s]/ && 
                         ! ($buffer =~ /^[0-9]+$/)  )
                 ||
                 ! $slice[1] ) {
@@ -245,10 +245,10 @@ sub _normalize {
         # (fixes problems with stuff like this ->
         # ==>  sagte er." Dieser wiederum )
         my $candidate; my $pos;
-        if ( $input[$i+1] =~ /^[A-Z]/ ) {
+        if ( $input[$i+1] && $input[$i+1] =~ /^[A-Z]/ ) {
             $candidate = $input[$i+1]; $pos = $i+1;
         }
-        elsif ( $input[$i+2] =~ /^[A-Z]/ ) {
+        elsif ( $input[$i+2] && $input[$i+2] =~ /^[A-Z]/ ) {
             $candidate = $input[$i+2]; $pos = $i+2;
         }
         
@@ -256,7 +256,8 @@ sub _normalize {
         
         print "\tnormalize '$candidate' [pos: $pos]?\t" if $debug;
         $input[$pos] = lcfirst ( $input[$pos] )
-            if ( $filter{lc($input[$pos])} >= $filter{$input[$pos]} );
+            if ( $filter{lcfirst($input[$pos])} &&
+                    $filter{lcfirst($input[$pos])} >= $filter{$input[$pos]} );
         print "-> '$input[$pos]'\n" if $debug;
     }
 
